==> haskell-base-prelude-1.0.1.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.0.1.1
id: base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP
key: base-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    BasePrelude
abi: 79cf058bfa5a9fe6e4e300898f5910e6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-prelude-1.0.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-prelude-1.0.1.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/base-prelude-1.0.1.1
hs-libraries: HSbase-prelude-1.0.1.1-50PByGWQp6O3J1SglYyZmP
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-prelude-1.2.0.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-base-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-prelude
version: 1.2.0.1
id: base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
key: base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/base-prelude
synopsis: The most complete prelude formed solely from the "base" package
description:
    A library which aims to reexport all the non-conflicting and
    most general definitions from the \"base\" package.
    This includes APIs for applicatives, arrows, monoids, foldables, traversables,
    exceptions, generics, ST, MVars and STM.
    .
    This package will never have any dependencies other than \"base\".
    .
    /Versioning policy/
    .
    The versioning policy of this package deviates from PVP in the sense
    that its exports in part are transitively determined by the version of \"base\".
    Therefore it'\''s recommended for the users of \"base-prelude\" to specify
    the bounds of \"base\" as well.
category: Prelude
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    BasePrelude
abi: b34774796b8ca753bd00f29b97b8d6b7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-prelude-1.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-prelude-1.2.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/base-prelude-1.2.0.1
hs-libraries: HSbase-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-base-prelude/html/base-prelude.haddock
haddock-html: /usr/share/doc/haskell-base-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
